import { Input, Card, Select, Button, message, InputNumber } from 'antd';
import { useEffect, useState } from 'react';
import { Form } from 'antd';
import { history } from 'umi';
import ProCard from '@ant-design/pro-card';
import { UploadImage } from '@/components/Upload';
import ExtendContent from '@/components/ExtendContent';
import { addBanner, updateBanner } from '@/services/banner';

const { Option } = Select;
const goBack = () => {
  history.goBack();
};
const FormItem = Form.Item;
export default (props) => {
  const { data } = props.location;

  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const [image, setImage] = useState();

  const formItemLayout = {
    //布局
    labelCol: { span: 6 },
    wrapperCol: { span: 14 },
  };

  const Submit = (values) => {
    setLoading(true);
    if (data) {
      updateBanner(data.bannerId, values)
        .then(() => {
          setLoading(false);
          message.success('数据更新成功');
          goBack();
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    } else {
      addBanner(values)
        .then((res) => {
          setLoading(false);
          message.success('数据保存成功');
          goBack();
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    }
  };
  useEffect(() => {
    if (data) {
      form.setFieldsValue(data);
    }
  }, [data]);
  return (
    <Card>
      <ProCard tabs={{ type: 'card' }} style={{ marginTop: '16px' }}>
        <ProCard.TabPane key={1} tab="广告位管理">
          <Form {...formItemLayout} onFinish={Submit} form={form}>
            <FormItem label="名称" name="title" rules={[{ required: true, message: '请输入' }]}>
              <Input placeholder="请输入" style={{ width: '350px' }} />
            </FormItem>
            <FormItem label="图片" name="thumb" rules={[{ required: true, message: '请选择' }]} tooltip='轮播图尺寸建议5:3这样小程序可以更好地显示'>
              <UploadImage value={image} onChange={setImage} />
            </FormItem>
            <FormItem label="位置" name="position" rules={[{ required: true, message: '请选择' }]}>
              <Select style={{ width: '350px' }}>
                <Option value="index" key="index">
                  首次引导页
                </Option>
                <Option value="appIndex" key="appIndex">
                  app启动页
                </Option>
                <Option value="banner" key="banner">
                  农户轮播图
                </Option>
                <Option value="bannerWorker" key="bannerWorker">
                  农机手轮播图
                </Option>
              </Select>
            </FormItem>
            <FormItem label="排序" name="sortNo" rules={[{ required: true, message: '请输入' }]}>
              <InputNumber min={0} placeholder="请输入排序" style={{ width: '350px' }} />
            </FormItem>
            {/* <FormItem label="详细信息" colon={false}>
              <ExtendContent
                targetType="tourist"
                targetId={'66'}
                onCancel={() => history.goBack()}
              />
            </FormItem> */}
            <FormItem label=" " colon={false}>
              <Button type="default" onClick={() => goBack()}>
                返回
              </Button>
              <Button
                type="primary"
                loading={loading}
                htmlType="Submit"
                style={{ marginLeft: '4em' }}
              >
                保存
              </Button>
            </FormItem>
          </Form>
        </ProCard.TabPane>
      </ProCard>
    </Card>
  );
};
