import { useState, useEffect } from 'react';
import { Form, Input, Card, DatePicker, Select, InputNumber, message, Button } from 'antd';
import { history } from 'umi';
import ProCard from '@ant-design/pro-card';
import ExtendContent from '@/components/ExtendContent';
import { UploadImage, UploadImageList } from '@/components/Upload';
import Money from '@/components/Money';
import { addMachinery, updateMachinery, getMachineryDetail } from '@/services/machinery';
import { getMachineryTypeList } from '@/services/machineryType';
import { getRegionList } from '@/services/region';
import { getCooperativeList } from '@/services/cooperative';
import moment from 'moment';

const { Option } = Select;
const formItemLayout = { labelCol: { span: 6 }, wrapperCol: { span: 14 } };

const goBack = () => {
  history.goBack();
};
const FormItem = Form.Item;
export default (props) => {
  const { location } = props;
  const { id } = location.query;
  const [form] = Form.useForm();
  const [loading, setLoading] = useState(false);
  const [imageList, setImageList] = useState([]);
  //农机类型列表
  const [machineryTypeList, setMachineryTypeList] = useState([]);
  //区域列表
  const [regionList, setRegionList] = useState([]);
  //合作社列表
  const [cooperativeList, setCooperativeList] = useState([]);

  const Submit = (data) => {
    var newData = { ...data }
    if (data.buyDate) {
      newData = { ...data, buyDate: data.buyDate.format('YYYY-MM-DD HH:mm:ss') };
    }
    setLoading(true);

    if (id) {
      updateMachinery(id, newData)
        .then(() => {
          setLoading(false);
          message.success('数据更新成功');
          goBack();
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    } else {
      addMachinery(newData)
        .then((res) => {
          setLoading(false);
          message.success('数据保存成功');
          goBack();
        })
        .catch((err) => {
          setLoading(false);
          message.error(err.message || err);
        });
    }
  };

  const onDateChange = () => { };
  const imageInput = (image) => {
    return {
      uid: image.imageId,
      url: image.url,
    };
  };

  const imageOutput = (image) => {
    return {
      imageId: image?.raw?.imageId,
      targetId: id,
      url: image.url,
    };
  };
  useEffect(() => {
    getMachineryTypeList({ pageSize: 999 }).then((res) => {
      setMachineryTypeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
    getRegionList({ pageSize: 999 }).then((res) => {
      setRegionList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
    getCooperativeList({ pageSize: 999 }).then((res) => {
      setCooperativeList(res.records);
    }).catch((err) => {
      console.log(err.message)
    });
    if (id) {
      getMachineryDetail(id).then((res) => {
        form.setFieldsValue({ ...res, buyDate: res.buyDate ? moment(res.buyDate, 'YYYY-MM-DD') : null });
      }).catch((err) => {
        console.log(err.message)
      });
    }
  }, [id]);

  return (
    <Card>
      <ProCard tabs={{ type: 'card' }}>
        <ProCard.TabPane key={1} tab="农机编辑">
          <Form {...formItemLayout} onFinish={Submit} form={form}>
            <FormItem
              label="农机名"
              name="name"
              rules={[{ required: true, message: '请输入农机名' }]}
            >
              <Input placeholder="请输入农机名" style={{ width: '350px' }} />
            </FormItem>
            <FormItem
              label="农机类型"
              name="typeId"
              rules={[{ required: true, message: '请选择农机类型' }]}
            >
              <Select style={{ width: '350px' }}>
                {machineryTypeList.map((item) => (
                  <Option value={item.typeId} key={item.typeId}>
                    {item.name}
                  </Option>
                ))}
              </Select>
            </FormItem>
            <FormItem label="主图" name="thumb" rules={[{ required: true, message: '请选择主图' }]}>
              <UploadImage />
            </FormItem>
            <FormItem label="农机banner图集" name="images">
              <UploadImageList
                value={imageList}
                onChange={setImageList}
                input={imageInput}
                output={imageOutput}
              />
            </FormItem>
            <FormItem
              label="区域"
              name="regionId"
              rules={[{ required: true, message: '请选择区域' }]}
            >
              <Select style={{ width: '350px' }}>
                {regionList.map((item) => (
                  <Option value={item.regionId} key={item.regionId}>
                    {item.name}
                  </Option>
                ))}
              </Select>
            </FormItem>
            <FormItem
              label="归属合作社"
              name="orgId"
              rules={[{ required: true, message: '请选择归属合作社' }]}
            >
              <Select style={{ width: '350px' }}>
                {cooperativeList.map((item) => (
                  <Option value={item.orgId} key={item.orgId}>
                    {item.name}
                  </Option>
                ))}
              </Select>
            </FormItem>
            <FormItem label="单价" name="price" rules={[{ required: true, message: '请输入价格' }]}>
              <Money style={{ width: '350px' }} />
            </FormItem>
            <FormItem label="购买时间" name="buyDate">
              <DatePicker format="YYYY-MM-DD" onChange={onDateChange} style={{ width: '350px' }} />
            </FormItem>
            <FormItem label="状态" name="status" rules={[{ required: true, message: '请选择' }]}>
              <Select placeholder="请选择农机状态" style={{ width: '350px' }}>
                <Option value={1}>正常</Option>
                <Option value={0}>维修</Option>
              </Select>
            </FormItem>
            {id && (
              <FormItem label="详细信息" colon={false}>
                <ExtendContent targetType="machinery" targetId={id} onCancel={goBack} />
              </FormItem>
            )}
            <FormItem label=" " colon={false}>
              <Button type="default" onClick={goBack}>
                返回
              </Button>
              <Button
                type="primary"
                loading={loading}
                htmlType="submit"
                style={{ marginLeft: '4em' }}
              >
                保存
              </Button>
            </FormItem>
          </Form>
        </ProCard.TabPane>
      </ProCard>
    </Card>
  );
};
