import React, { useState, useRef } from 'react';
import { DatePicker } from 'antd';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import moment from 'moment';
import PageTable from '@/components/PageTable';
import { getUserList } from '@/services/user'

const formatterTime = (val) => {
  return val ? moment(val).format('YYYY-MM-DD HH:mm') : '';
};
const { RangePicker } = DatePicker;

export default (props) => {
  const [start, setStartDate] = useState()
  const [end, setEndDate] = useState()

  const handelChange = (date, dateStrings) => {
    setStartDate(dateStrings[0])
    setEndDate(dateStrings[1])
  }
  const ref = useRef();
  const Reset = () => {
    setStartDate()
    setEndDate()
    ref.current.reload();
  }

  const columns = [
    {
      title: '姓名',
      dataIndex: 'name',
      key: 'name',
    },
    {
      title: '头像',
      dataIndex: 'avatar',
      key: 'avatar',
      search: false
    },
    {
      title: '手机号',
      dataIndex: 'phone',
      key: 'phone',
    },
    {
      title: '身份',
      dataIndex: 'type',
      key: 'type',
      dataIndex: 'position',
      render: (_, record) => {
        return record.position === 'farmer'
          ? '农户'
          : record.position === 'worker'
            ? '农机手' : ''
      },
      valueType: 'select',
      valueEnum: {
        'farmer': { text: '农户' },
        'worker': { text: '农机手' },
      },
    },

    {
      title: '注册时间',
      dataIndex: 'createDate',
      key: 'createDate',
      render: (t, render) => formatterTime(render.createDate),
      renderFormItem: (_, record) => <RangePicker placeholder={['开始日期', '结束日期']} format='YYYY-MM-DD' onChange={handelChange} />
    },
  ];

  return (
    <PageHeaderWrapper>
      <PageTable
        actionRef={ref}
        request={getUserList}
        // expfunc={exportPersonList}
        columns={columns}
        rowKey="userId"
        params={{ start, end }}
        onReset={Reset}
        options={false}
      />
    </PageHeaderWrapper>
  );
};
